==> projen-0.45.3-sources.jar: io/github/cdklabs/projen/java/Pom.java <==
package io.github.cdklabs.projen.java;

/**
 * (experimental) A Project Object Model or POM is the fundamental unit of work in Maven.
 * <p>
 * It is
 * an XML file that contains information about the project and configuration
 * details used by Maven to build the project.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.47.0 (build 86d2c33)", date = "2021-12-20T00:39:28.825Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.java.Pom")
public class Pom extends io.github.cdklabs.projen.Component {

    protected Pom(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected Pom(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param project This parameter is required.
     * @param options This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public Pom(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Project project, final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.java.PomOptions options) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required"), java.util.Objects.requireNonNull(options, "options is required") });
    }

    /**
     * (experimental) Adds a runtime dependency.
     * <p>
     * @param spec Format `<groupId>/<artifactId>@<semver>`. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public void addDependency(final @org.jetbrains.annotations.NotNull java.lang.String spec) {
        software.amazon.jsii.Kernel.call(this, "addDependency", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(spec, "spec is required") });
    }

    /**
     * (experimental) Adds a build plugin to the pom.
     * <p>
     * The plug in is also added as a BUILD dep to the project.
     * <p>
     * @param spec dependency spec (`group/artifact@version`). This parameter is required.
     * @param options plugin options.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Dependency addPlugin(final @org.jetbrains.annotations.NotNull java.lang.String spec, final @org.jetbrains.annotations.Nullable io.github.cdklabs.projen.java.PluginOptions options) {
        return software.amazon.jsii.Kernel.call(this, "addPlugin", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.Dependency.class), new Object[] { java.util.Objects.requireNonNull(spec, "spec is required"), options });
    }

    /**
     * (experimental) Adds a build plugin to the pom.
     * <p>
     * The plug in is also added as a BUILD dep to the project.
     * <p>
     * @param spec dependency spec (`group/artifact@version`). This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Dependency addPlugin(final @org.jetbrains.annotations.NotNull java.lang.String spec) {
        return software.amazon.jsii.Kernel.call(this, "addPlugin", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.Dependency.class), new Object[] { java.util.Objects.requireNonNull(spec, "spec is required") });
    }

    /**
     * (experimental) Adds a key/value property to the pom.
     * <p>
     * @param key the key. This parameter is required.
     * @param value the value. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public void addProperty(final @org.jetbrains.annotations.NotNull java.lang.String key, final @org.jetbrains.annotations.NotNull java.lang.String value) {
        software.amazon.jsii.Kernel.call(this, "addProperty", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(key, "key is required"), java.util.Objects.requireNonNull(value, "value is required") });
    }

    /**
     * (experimental) Adds a test dependency.
     * <p>
     * @param spec Format `<groupId>/<artifactId>@<semver>`. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public void addTestDependency(final @org.jetbrains.annotations.NotNull java.lang.String spec) {
        software.amazon.jsii.Kernel.call(this, "addTestDependency", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(spec, "spec is required") });
    }

    /**
     * (experimental) Maven artifact ID.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.lang.String getArtifactId() {
        return software.amazon.jsii.Kernel.get(this, "artifactId", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     * (experimental) The name of the pom file.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.lang.String getFileName() {
        return software.amazon.jsii.Kernel.get(this, "fileName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     * (experimental) Maven group ID.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.lang.String getGroupId() {
        return software.amazon.jsii.Kernel.get(this, "groupId", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     * (experimental) Maven packaging format.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.lang.String getPackaging() {
        return software.amazon.jsii.Kernel.get(this, "packaging", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     * (experimental) Project version.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.lang.String getVersion() {
        return software.amazon.jsii.Kernel.get(this, "version", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     * (experimental) Project description.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.Nullable java.lang.String getDescription() {
        return software.amazon.jsii.Kernel.get(this, "description", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     * (experimental) Project display name.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.Nullable java.lang.String getName() {
        return software.amazon.jsii.Kernel.get(this, "name", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     * (experimental) Project URL.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.Nullable java.lang.String getUrl() {
        return software.amazon.jsii.Kernel.get(this, "url", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     * (experimental) A fluent builder for {@link io.github.cdklabs.projen.java.Pom}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<io.github.cdklabs.projen.java.Pom> {
        /**
         * @return a new instance of {@link Builder}.
         * @param project This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public static Builder create(final io.github.cdklabs.projen.Project project) {
            return new Builder(project);
        }

        private final io.github.cdklabs.projen.Project project;
        private final io.github.cdklabs.projen.java.PomOptions.Builder options;

        private Builder(final io.github.cdklabs.projen.Project project) {
            this.project = project;
            this.options = new io.github.cdklabs.projen.java.PomOptions.Builder();
        }

        /**
         * (experimental) The artifactId is generally the name that the project is known by.
         * <p>
         * Although
         * the groupId is important, people within the group will rarely mention the
         * groupId in discussion (they are often all be the same ID, such as the
         * MojoHaus project groupId: org.codehaus.mojo). It, along with the groupId,
         * creates a key that separates this project from every other project in the
         * world (at least, it should :) ). Along with the groupId, the artifactId
         * fully defines the artifact's living quarters within the repository. In the
         * case of the above project, my-project lives in
         * $M2_REPO/org/codehaus/mojo/my-project.
         * <p>
         * Default: "my-app"
         * <p>
         * @return {@code this}
         * @param artifactId The artifactId is generally the name that the project is known by. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder artifactId(final java.lang.String artifactId) {
            this.options.artifactId(artifactId);
            return this;
        }

        /**
         * (experimental) This is generally unique amongst an organization or a project.
         * <p>
         * For example,
         * all core Maven artifacts do (well, should) live under the groupId
         * org.apache.maven. Group ID's do not necessarily use the dot notation, for
         * example, the junit project. Note that the dot-notated groupId does not have
         * to correspond to the package structure that the project contains. It is,
         * however, a good practice to follow. When stored within a repository, the
         * group acts much like the Java packaging structure does in an operating
         * system. The dots are replaced by OS specific directory separators (such as
         * '/' in Unix) which becomes a relative directory structure from the base
         * repository. In the example given, the org.codehaus.mojo group lives within
         * the directory $M2_REPO/org/codehaus/mojo.
         * <p>
         * Default: "org.acme"
         * <p>
         * @return {@code this}
         * @param groupId This is generally unique amongst an organization or a project. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder groupId(final java.lang.String groupId) {
            this.options.groupId(groupId);
            return this;
        }

        /**
         * (experimental) This is the last piece of the naming puzzle.
         * <p>
         * groupId:artifactId denotes a
         * single project but they cannot delineate which incarnation of that project
         * we are talking about. Do we want the junit:junit of 2018 (version 4.12), or
         * of 2007 (version 3.8.2)? In short: code changes, those changes should be
         * versioned, and this element keeps those versions in line. It is also used
         * within an artifact's repository to separate versions from each other.
         * my-project version 1.0 files live in the directory structure
         * $M2_REPO/org/codehaus/mojo/my-project/1.0.
         * <p>
         * Default: "0.1.0"
         * <p>
         * @return {@code this}
         * @param version This is the last piece of the naming puzzle. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder version(final java.lang.String version) {
            this.options.version(version);
            return this;
        }

        /**
         * (experimental) Description of a project is always good.
         * <p>
         * Although this should not replace
         * formal documentation, a quick comment to any readers of the POM is always
         * helpful.
         * <p>
         * Default: undefined
         * <p>
         * @return {@code this}
         * @param description Description of a project is always good. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder description(final java.lang.String description) {
            this.options.description(description);
            return this;
        }

        /**
         * (experimental) Project packaging format.
         * <p>
         * Default: "jar"
         * <p>
         * @return {@code this}
         * @param packaging Project packaging format. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder packaging(final java.lang.String packaging) {
            this.options.packaging(packaging);
            return this;
        }

        /**
         * (experimental) The URL, like the name, is not required.
         * <p>
         * This is a nice gesture for
         * projects users, however, so that they know where the project lives.
         * <p>
         * Default: undefined
         * <p>
         * @return {@code this}
         * @param url The URL, like the name, is not required. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder url(final java.lang.String url) {
            this.options.url(url);
            return this;
        }

        /**
         * @returns a newly built instance of {@link io.github.cdklabs.projen.java.Pom}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public io.github.cdklabs.projen.java.Pom build() {
            return new io.github.cdklabs.projen.java.Pom(
                this.project,
                this.options.build()
            );
        }
    }
}

==> projen-0.79.0-sources.jar: io/github/cdklabs/projen/java/Pom.java <==
package io.github.cdklabs.projen.java;

/**
 * (experimental) A Project Object Model or POM is the fundamental unit of work in Maven.
 * <p>
 * It is
 * an XML file that contains information about the project and configuration
 * details used by Maven to build the project.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.94.0 (build b380f01)", date = "2024-01-10T23:18:45.492Z")
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
@software.amazon.jsii.Jsii(module = io.github.cdklabs.projen.$Module.class, fqn = "projen.java.Pom")
public class Pom extends io.github.cdklabs.projen.Component {

    protected Pom(final software.amazon.jsii.JsiiObjectRef objRef) {
        super(objRef);
    }

    protected Pom(final software.amazon.jsii.JsiiObject.InitializationMode initializationMode) {
        super(initializationMode);
    }

    /**
     * @param project This parameter is required.
     * @param options This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public Pom(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Project project, final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.java.PomOptions options) {
        super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
        software.amazon.jsii.JsiiEngine.getInstance().createNewObject(this, new Object[] { java.util.Objects.requireNonNull(project, "project is required"), java.util.Objects.requireNonNull(options, "options is required") });
    }

    /**
     * (experimental) Adds a runtime dependency.
     * <p>
     * @param spec Format <code>&lt;groupId&gt;/&lt;artifactId&gt;&#64;&lt;semver&gt;</code>. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public void addDependency(final @org.jetbrains.annotations.NotNull java.lang.String spec) {
        software.amazon.jsii.Kernel.call(this, "addDependency", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(spec, "spec is required") });
    }

    /**
     * (experimental) Adds a build plugin to the pom.
     * <p>
     * The plug in is also added as a BUILD dep to the project.
     * <p>
     * @param spec dependency spec (<code>group/artifact&#64;version</code>). This parameter is required.
     * @param options plugin options.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Dependency addPlugin(final @org.jetbrains.annotations.NotNull java.lang.String spec, final @org.jetbrains.annotations.Nullable io.github.cdklabs.projen.java.PluginOptions options) {
        return software.amazon.jsii.Kernel.call(this, "addPlugin", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.Dependency.class), new Object[] { java.util.Objects.requireNonNull(spec, "spec is required"), options });
    }

    /**
     * (experimental) Adds a build plugin to the pom.
     * <p>
     * The plug in is also added as a BUILD dep to the project.
     * <p>
     * @param spec dependency spec (<code>group/artifact&#64;version</code>). This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.Dependency addPlugin(final @org.jetbrains.annotations.NotNull java.lang.String spec) {
        return software.amazon.jsii.Kernel.call(this, "addPlugin", software.amazon.jsii.NativeType.forClass(io.github.cdklabs.projen.Dependency.class), new Object[] { java.util.Objects.requireNonNull(spec, "spec is required") });
    }

    /**
     * (experimental) Adds a key/value property to the pom.
     * <p>
     * @param key the key. This parameter is required.
     * @param value the value. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public void addProperty(final @org.jetbrains.annotations.NotNull java.lang.String key, final @org.jetbrains.annotations.NotNull java.lang.String value) {
        software.amazon.jsii.Kernel.call(this, "addProperty", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(key, "key is required"), java.util.Objects.requireNonNull(value, "value is required") });
    }

    /**
     * (experimental) Adds a repository to the pom.
     * <p>
     * @param repository the repository to add. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public void addRepository(final @org.jetbrains.annotations.NotNull io.github.cdklabs.projen.java.MavenRepository repository) {
        software.amazon.jsii.Kernel.call(this, "addRepository", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(repository, "repository is required") });
    }

    /**
     * (experimental) Adds a test dependency.
     * <p>
     * @param spec Format <code>&lt;groupId&gt;/&lt;artifactId&gt;&#64;&lt;semver&gt;</code>. This parameter is required.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public void addTestDependency(final @org.jetbrains.annotations.NotNull java.lang.String spec) {
        software.amazon.jsii.Kernel.call(this, "addTestDependency", software.amazon.jsii.NativeType.VOID, new Object[] { java.util.Objects.requireNonNull(spec, "spec is required") });
    }

    /**
     * (experimental) Maven artifact ID.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.lang.String getArtifactId() {
        return software.amazon.jsii.Kernel.get(this, "artifactId", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     * (experimental) The name of the pom file.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.lang.String getFileName() {
        return software.amazon.jsii.Kernel.get(this, "fileName", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     * (experimental) Maven group ID.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.lang.String getGroupId() {
        return software.amazon.jsii.Kernel.get(this, "groupId", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     * (experimental) Maven packaging format.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.lang.String getPackaging() {
        return software.amazon.jsii.Kernel.get(this, "packaging", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     * (experimental) Project version.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.NotNull java.lang.String getVersion() {
        return software.amazon.jsii.Kernel.get(this, "version", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     * (experimental) Project description.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.Nullable java.lang.String getDescription() {
        return software.amazon.jsii.Kernel.get(this, "description", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     * (experimental) Project display name.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.Nullable java.lang.String getName() {
        return software.amazon.jsii.Kernel.get(this, "name", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     * (experimental) Project URL.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public @org.jetbrains.annotations.Nullable java.lang.String getUrl() {
        return software.amazon.jsii.Kernel.get(this, "url", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
    }

    /**
     * (experimental) A fluent builder for {@link io.github.cdklabs.projen.java.Pom}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
    public static final class Builder implements software.amazon.jsii.Builder<io.github.cdklabs.projen.java.Pom> {
        /**
         * @return a new instance of {@link Builder}.
         * @param project This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public static Builder create(final io.github.cdklabs.projen.Project project) {
            return new Builder(project);
        }

        private final io.github.cdklabs.projen.Project project;
        private final io.github.cdklabs.projen.java.PomOptions.Builder options;

        private Builder(final io.github.cdklabs.projen.Project project) {
            this.project = project;
            this.options = new io.github.cdklabs.projen.java.PomOptions.Builder();
        }

        /**
         * (experimental) The artifactId is generally the name that the project is known by.
         * <p>
         * Although
         * the groupId is important, people within the group will rarely mention the
         * groupId in discussion (they are often all be the same ID, such as the
         * MojoHaus project groupId: org.codehaus.mojo). It, along with the groupId,
         * creates a key that separates this project from every other project in the
         * world (at least, it should :) ). Along with the groupId, the artifactId
         * fully defines the artifact's living quarters within the repository. In the
         * case of the above project, my-project lives in
         * $M2_REPO/org/codehaus/mojo/my-project.
         * <p>
         * Default: "my-app"
         * <p>
         * @return {@code this}
         * @param artifactId The artifactId is generally the name that the project is known by. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder artifactId(final java.lang.String artifactId) {
            this.options.artifactId(artifactId);
            return this;
        }

        /**
         * (experimental) This is generally unique amongst an organization or a project.
         * <p>
         * For example,
         * all core Maven artifacts do (well, should) live under the groupId
         * org.apache.maven. Group ID's do not necessarily use the dot notation, for
         * example, the junit project. Note that the dot-notated groupId does not have
         * to correspond to the package structure that the project contains. It is,
         * however, a good practice to follow. When stored within a repository, the
         * group acts much like the Java packaging structure does in an operating
         * system. The dots are replaced by OS specific directory separators (such as
         * '/' in Unix) which becomes a relative directory structure from the base
         * repository. In the example given, the org.codehaus.mojo group lives within
         * the directory $M2_REPO/org/codehaus/mojo.
         * <p>
         * Default: "org.acme"
         * <p>
         * @return {@code this}
         * @param groupId This is generally unique amongst an organization or a project. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder groupId(final java.lang.String groupId) {
            this.options.groupId(groupId);
            return this;
        }

        /**
         * (experimental) This is the last piece of the naming puzzle.
         * <p>
         * groupId:artifactId denotes a
         * single project but they cannot delineate which incarnation of that project
         * we are talking about. Do we want the junit:junit of 2018 (version 4.12), or
         * of 2007 (version 3.8.2)? In short: code changes, those changes should be
         * versioned, and this element keeps those versions in line. It is also used
         * within an artifact's repository to separate versions from each other.
         * my-project version 1.0 files live in the directory structure
         * $M2_REPO/org/codehaus/mojo/my-project/1.0.
         * <p>
         * Default: "0.1.0"
         * <p>
         * @return {@code this}
         * @param version This is the last piece of the naming puzzle. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder version(final java.lang.String version) {
            this.options.version(version);
            return this;
        }

        /**
         * (experimental) Description of a project is always good.
         * <p>
         * Although this should not replace
         * formal documentation, a quick comment to any readers of the POM is always
         * helpful.
         * <p>
         * Default: undefined
         * <p>
         * @return {@code this}
         * @param description Description of a project is always good. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder description(final java.lang.String description) {
            this.options.description(description);
            return this;
        }

        /**
         * (experimental) Project packaging format.
         * <p>
         * Default: "jar"
         * <p>
         * @return {@code this}
         * @param packaging Project packaging format. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder packaging(final java.lang.String packaging) {
            this.options.packaging(packaging);
            return this;
        }

        /**
         * (experimental) The URL, like the name, is not required.
         * <p>
         * This is a nice gesture for
         * projects users, however, so that they know where the project lives.
         * <p>
         * Default: undefined
         * <p>
         * @return {@code this}
         * @param url The URL, like the name, is not required. This parameter is required.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        public Builder url(final java.lang.String url) {
            this.options.url(url);
            return this;
        }

        /**
         * @return a newly built instance of {@link io.github.cdklabs.projen.java.Pom}.
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Experimental)
        @Override
        public io.github.cdklabs.projen.java.Pom build() {
            return new io.github.cdklabs.projen.java.Pom(
                this.project,
                this.options.build()
            );
        }
    }
}
